@@ -171,19 +171,19 @@ class CasperLabsClient:
         public_key_hex: str = None,
         algorithm: str = ED25519_KEY_ALGORITHM,
         payment: Union[Path, str] = None,
-        payment_args: bytes = None,
+        payment_args: Union[bytes, str] = None,
         payment_amount: int = None,
-        payment_hash: bytes = None,
+        payment_hash: Union[bytes, str] = None,
         payment_name: str = None,
-        payment_package_hash: bytes = None,
+        payment_package_hash: Union[bytes, str] = None,
         payment_package_name: str = None,
         payment_entry_point: str = None,
         payment_version: int = None,
         session: Union[Path, str] = None,
-        session_args: bytes = None,
-        session_hash: bytes = None,
+        session_args: Union[bytes, str] = None,
+        session_hash: Union[bytes, str] = None,
         session_name: str = None,
-        session_package_hash: bytes = None,
+        session_package_hash: Union[bytes, str] = None,
         session_package_name: str = None,
         session_entry_point: str = None,
         session_version: int = None,
@@ -306,19 +306,19 @@ class CasperLabsClient:
         private_key_hex: str = None,
         algorithm: str = ED25519_KEY_ALGORITHM,
         payment: Union[Path, str] = None,
-        payment_args: bytes = None,
+        payment_args: Union[bytes, str] = None,
         payment_amount: int = None,
-        payment_hash: bytes = None,
+        payment_hash: Union[bytes, str] = None,
         payment_name: str = None,
-        payment_package_hash: bytes = None,
+        payment_package_hash: Union[bytes, str] = None,
         payment_package_name: str = None,
         payment_entry_point: str = None,
         payment_version: int = None,
         session: Union[Path, str] = None,
-        session_args: bytes = None,
-        session_hash: bytes = None,
+        session_args: Union[bytes, str] = None,
+        session_hash: Union[bytes, str] = None,
         session_name: str = None,
-        session_package_hash: bytes = None,
+        session_package_hash: Union[bytes, str] = None,
         session_package_name: str = None,
         session_entry_point: str = None,
         session_version: int = None,
@@ -415,11 +415,11 @@ class CasperLabsClient:
         private_key_hex: str = None,
         algorithm: str = ED25519_KEY_ALGORITHM,
         payment: str = None,
-        payment_args: bytes = None,
+        payment_args: Union[bytes, str] = None,
         payment_amount: int = None,
-        payment_hash: bytes = None,
+        payment_hash: Union[bytes, str] = None,
         payment_name: str = None,
-        payment_package_hash: bytes = None,
+        payment_package_hash: Union[bytes, str] = None,
         payment_package_name: str = None,
         payment_entry_point: str = None,
         payment_version: int = None,
